@@ -34,20 +34,15 @@ class ItemEncryptedSettings;
 
 class QIODevice;
 
-class ItemEncrypted : public QWidget, public ItemWidget
+class ItemEncrypted final : public QWidget, public ItemWidget
 {
     Q_OBJECT
 
 public:
     explicit ItemEncrypted(QWidget *parent);
-
-    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                              const QModelIndex &index) const override;
 };
 
-class ItemEncryptedSaver : public QObject, public ItemSaverInterface
+class ItemEncryptedSaver final : public QObject, public ItemSaverInterface
 {
     Q_OBJECT
 
@@ -61,7 +56,7 @@ private:
     void emitEncryptFailed();
 };
 
-class ItemEncryptedScriptable : public ItemScriptable
+class ItemEncryptedScriptable final : public ItemScriptable
 {
     Q_OBJECT
 public slots:
@@ -86,7 +81,7 @@ private:
     QByteArray decrypt(const QByteArray &bytes);
 };
 
-class ItemEncryptedLoader : public QObject, public ItemLoaderInterface
+class ItemEncryptedLoader final : public QObject, public ItemLoaderInterface
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID COPYQ_PLUGIN_ITEM_LOADER_ID)
@@ -129,6 +124,10 @@ public:
 
     QVector<Command> commands() const override;
 
+    bool data(QVariantMap *data, const QModelIndex &) const override;
+
+    bool setData(const QVariantMap &data, const QModelIndex &index, QAbstractItemModel *model) const override;
+
 signals:
     void error(const QString &);
 
