@@ -21,6 +21,7 @@
 #include "ui_itemtextsettings.h"
 
 #include "common/mimetypes.h"
+#include "common/sanitize_text_document.h"
 #include "common/textdata.h"
 
 #include <QAbstractTextDocumentLayout>
@@ -163,6 +164,9 @@ ItemText::ItemText(const QString &text, const QString &richText, int maxLines, i
         }
     }
 
+    if (m_isRichText)
+        sanitizeTextDocument(&m_textDocument);
+
     setDocument(&m_textDocument);
 
     connect( this, &QTextEdit::selectionChanged,
