@@ -21,6 +21,7 @@
 
 #include "common/command.h"
 #include "common/common.h"
+#include "common/config.h"
 #include "common/mimetypes.h"
 #include "common/settings.h"
 #include "common/temporarysettings.h"
@@ -149,13 +150,13 @@ Commands importCommands(QSettings *settings)
 
 Commands loadAllCommands()
 {
-    QSettings settings;
-    return loadCommands(&settings);
+    const QString commandConfigPath = getConfigurationFilePath("-commands.ini");
+    return importCommandsFromFile(commandConfigPath);
 }
 
 void saveCommands(const Commands &commands)
 {
-    Settings settings;
+    Settings settings(getConfigurationFilePath("-commands.ini"));
     saveCommands(commands, settings.settingsData());
 }
 
@@ -171,11 +172,20 @@ Commands loadCommands(QSettings *settings)
         settings->endGroup();
     }
 
-    int size = settings->beginReadArray("Commands");
-
-    for(int i=0; i<size; ++i) {
-        settings->setArrayIndex(i);
-        loadCommand(*settings, &commands);
+    const int size = settings->beginReadArray("Commands");
+    // Allow undefined "size" for the array in settings.
+    if (size == 0) {
+        for (int i = 0; ; ++i) {
+            settings->setArrayIndex(i);
+            if ( settings->childKeys().isEmpty() )
+                break;
+            loadCommand(*settings, &commands);
+        }
+    } else {
+        for (int i = 0; i < size; ++i) {
+            settings->setArrayIndex(i);
+            loadCommand(*settings, &commands);
+        }
     }
 
     settings->endArray();
