@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -39,7 +39,7 @@ Q_DECLARE_METATYPE(Command)
 
 namespace {
 
-class CommandModel : public QAbstractListModel {
+class CommandModel final : public QAbstractListModel {
 public:
     explicit CommandModel(const QVector<Command> &commands, QObject *parent = nullptr)
         : QAbstractListModel(parent)
