@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -119,7 +119,7 @@ CommandWidget::CommandWidget(QWidget *parent)
     initTabComboBox(ui->comboBoxCopyToTab);
     initTabComboBox(ui->comboBoxOutputTab);
 
-    if ( !createPlatformNativeInterface()->canGetWindowTitle() )
+    if ( !platformNativeInterface()->canGetWindowTitle() )
         ui->lineEditWindow->hide();
 }
 
